@@ -207,7 +207,7 @@ class faciletoolkit:
         driver = BuiltIn().get_library_instance('SeleniumLibrary')
         faciletoolkit().dom_is_loaded(timeout)
         driver.wait_until_page_contains_element(locator, timeout)
-        driver.wait_until_element_is_visible(locator, timeout)
+        driver.wait_until_element_is_visible(locator, "1s")
         #da vedere se EC wrappa due condition in una e wrappare i due wait
         log_preventivo = BuiltIn().run_keyword_and_return_status("should_contain", locator, "AS_result_content", None, True, False)
         if log_preventivo:
@@ -477,3 +477,8 @@ class faciletoolkit:
             if previous > actual:
                 raise(RobotError(str(previous) + " is bigger than " + str(actual)))
 
+    @staticmethod
+    @keyword
+    def wait_ajax(timeout="60s"):   
+        driver = BuiltIn().get_library_instance('SeleniumLibrary')
+        driver.wait_for_condition("return jQuery.active == 0", timeout)
\ No newline at end of file
